@@ -31,11 +31,18 @@ pub mod actions_download_workflow_run_attempt_logs;
 pub mod actions_download_workflow_run_logs;
 pub mod actions_enable_selected_repository_github_actions_organization;
 pub mod actions_enable_workflow;
+pub mod actions_get_actions_cache_usage;
+pub mod actions_get_actions_cache_usage_by_repo_for_org;
+pub mod actions_get_actions_cache_usage_for_enterprise;
+pub mod actions_get_actions_cache_usage_for_org;
 pub mod actions_get_allowed_actions_organization;
 pub mod actions_get_allowed_actions_repository;
 pub mod actions_get_artifact;
 pub mod actions_get_environment_public_key;
 pub mod actions_get_environment_secret;
+pub mod actions_get_github_actions_default_workflow_permissions_enterprise;
+pub mod actions_get_github_actions_default_workflow_permissions_organization;
+pub mod actions_get_github_actions_default_workflow_permissions_repository;
 pub mod actions_get_github_actions_permissions_organization;
 pub mod actions_get_github_actions_permissions_repository;
 pub mod actions_get_job_for_workflow_run;
@@ -49,6 +56,7 @@ pub mod actions_get_self_hosted_runner_for_org;
 pub mod actions_get_self_hosted_runner_for_repo;
 pub mod actions_get_self_hosted_runner_group_for_org;
 pub mod actions_get_workflow;
+pub mod actions_get_workflow_access_to_repository;
 pub mod actions_get_workflow_run;
 pub mod actions_get_workflow_run_attempt;
 pub mod actions_get_workflow_run_usage;
@@ -74,7 +82,9 @@ pub mod actions_list_self_hosted_runners_in_group_for_org;
 pub mod actions_list_workflow_run_artifacts;
 pub mod actions_list_workflow_runs;
 pub mod actions_list_workflow_runs_for_repo;
+pub mod actions_re_run_job_for_workflow_run;
 pub mod actions_re_run_workflow;
+pub mod actions_re_run_workflow_failed_jobs;
 pub mod actions_remove_all_custom_labels_from_self_hosted_runner_for_org;
 pub mod actions_remove_all_custom_labels_from_self_hosted_runner_for_repo;
 pub mod actions_remove_custom_label_from_self_hosted_runner_for_org;
@@ -87,12 +97,16 @@ pub mod actions_set_allowed_actions_organization;
 pub mod actions_set_allowed_actions_repository;
 pub mod actions_set_custom_labels_for_self_hosted_runner_for_org;
 pub mod actions_set_custom_labels_for_self_hosted_runner_for_repo;
+pub mod actions_set_github_actions_default_workflow_permissions_enterprise;
+pub mod actions_set_github_actions_default_workflow_permissions_organization;
+pub mod actions_set_github_actions_default_workflow_permissions_repository;
 pub mod actions_set_github_actions_permissions_organization;
 pub mod actions_set_github_actions_permissions_repository;
 pub mod actions_set_repo_access_to_self_hosted_runner_group_in_org;
 pub mod actions_set_selected_repos_for_org_secret;
 pub mod actions_set_selected_repositories_enabled_github_actions_organization;
 pub mod actions_set_self_hosted_runners_in_group_for_org;
+pub mod actions_set_workflow_access_to_repository;
 pub mod actions_update_self_hosted_runner_group_for_org;
 pub mod activity_check_repo_is_starred_by_authenticated_user;
 pub mod activity_delete_repo_subscription;
@@ -189,6 +203,7 @@ pub mod code_scanning_get_alert;
 pub mod code_scanning_get_analysis;
 pub mod code_scanning_get_sarif;
 pub mod code_scanning_list_alert_instances;
+pub mod code_scanning_list_alerts_for_org;
 pub mod code_scanning_list_alerts_for_repo;
 pub mod code_scanning_list_recent_analyses;
 pub mod code_scanning_update_alert;
@@ -198,16 +213,23 @@ pub mod codes_of_conduct_get_conduct_code;
 pub mod codespaces_add_repository_for_secret_for_authenticated_user;
 pub mod codespaces_codespace_machines_for_authenticated_user;
 pub mod codespaces_create_for_authenticated_user;
+pub mod codespaces_create_or_update_repo_secret;
 pub mod codespaces_create_or_update_secret_for_authenticated_user;
 pub mod codespaces_create_with_pr_for_authenticated_user;
 pub mod codespaces_create_with_repo_for_authenticated_user;
 pub mod codespaces_delete_for_authenticated_user;
+pub mod codespaces_delete_repo_secret;
 pub mod codespaces_delete_secret_for_authenticated_user;
+pub mod codespaces_export_for_authenticated_user;
+pub mod codespaces_get_export_details_for_authenticated_user;
 pub mod codespaces_get_for_authenticated_user;
 pub mod codespaces_get_public_key_for_authenticated_user;
+pub mod codespaces_get_repo_public_key;
+pub mod codespaces_get_repo_secret;
 pub mod codespaces_get_secret_for_authenticated_user;
 pub mod codespaces_list_for_authenticated_user;
 pub mod codespaces_list_in_repository_for_authenticated_user;
+pub mod codespaces_list_repo_secrets;
 pub mod codespaces_list_repositories_for_secret_for_authenticated_user;
 pub mod codespaces_list_secrets_for_authenticated_user;
 pub mod codespaces_remove_repository_for_secret_for_authenticated_user;
@@ -230,6 +252,7 @@ pub mod dependabot_list_repo_secrets;
 pub mod dependabot_list_selected_repos_for_org_secret;
 pub mod dependabot_remove_selected_repo_from_org_secret;
 pub mod dependabot_set_selected_repos_for_org_secret;
+pub mod dependency_graph_diff_range;
 pub mod emojis_get;
 pub mod enterprise_admin_add_custom_labels_to_self_hosted_runner_for_enterprise;
 pub mod enterprise_admin_add_org_access_to_self_hosted_runner_group_in_enterprise;
@@ -536,13 +559,14 @@ pub mod reactions_delete_for_commit_comment;
 pub mod reactions_delete_for_issue;
 pub mod reactions_delete_for_issue_comment;
 pub mod reactions_delete_for_pull_request_comment;
+pub mod reactions_delete_for_release;
 pub mod reactions_delete_for_team_discussion;
 pub mod reactions_delete_for_team_discussion_comment;
-pub mod reactions_delete_legacy;
 pub mod reactions_list_for_commit_comment;
 pub mod reactions_list_for_issue;
 pub mod reactions_list_for_issue_comment;
 pub mod reactions_list_for_pull_request_review_comment;
+pub mod reactions_list_for_release;
 pub mod reactions_list_for_team_discussion_comment_in_org;
 pub mod reactions_list_for_team_discussion_comment_legacy;
 pub mod reactions_list_for_team_discussion_in_org;
@@ -555,6 +579,7 @@ pub mod repos_add_team_access_restrictions;
 pub mod repos_add_user_access_restrictions;
 pub mod repos_check_collaborator;
 pub mod repos_check_vulnerability_alerts;
+pub mod repos_codeowners_errors;
 pub mod repos_compare_commits;
 pub mod repos_create_autolink;
 pub mod repos_create_commit_comment;
@@ -571,6 +596,7 @@ pub mod repos_create_or_update_environment;
 pub mod repos_create_or_update_file_contents;
 pub mod repos_create_pages_site;
 pub mod repos_create_release;
+pub mod repos_create_tag_protection;
 pub mod repos_create_using_template;
 pub mod repos_create_webhook;
 pub mod repos_decline_invitation_for_authenticated_user;
@@ -590,6 +616,7 @@ pub mod repos_delete_pages_site;
 pub mod repos_delete_pull_request_review_protection;
 pub mod repos_delete_release;
 pub mod repos_delete_release_asset;
+pub mod repos_delete_tag_protection;
 pub mod repos_delete_webhook;
 pub mod repos_disable_automated_security_fixes;
 pub mod repos_disable_lfs_for_repo;
@@ -671,6 +698,7 @@ pub mod repos_list_public;
 pub mod repos_list_pull_requests_associated_with_commit;
 pub mod repos_list_release_assets;
 pub mod repos_list_releases;
+pub mod repos_list_tag_protection;
 pub mod repos_list_tags;
 pub mod repos_list_teams;
 pub mod repos_list_webhook_deliveries;
